@extends('frontend.layouts.master')

@section('title', 'User Settings')

@section('content')

	<div class="container mt-4">
		<div class="row">
			<div class="col-sm-12">
				<h1>{{ $user->name }}</h1>
			</div>
		</div>
		<div class="row">
			<div class="col-md-3 col-sm-12 justify-content-center">
				<img src="{{ $user->image_half_url }}" alt="{{ $user->name }}" class="rounded img-fluid mx-auto d-block m-4">
				<form class="text-center" method="post" action="{{ route('frontend.account.avatar.update') }}" enctype="multipart/form-data">

					{{ csrf_field() }}
					{!! method_field('patch') !!}

					<label class="btn btn-primary btn-file">
						Select New Avatar<input type="file" name="avatar" style="display: none;" onchange="this.form.submit()">
					</label>
				</form>
			</div>
			<div class="col-md-9 col-sm-12 mt-4">
				<ul class="nav nav-tabs">
					<li class="nav-item">
						<a class="nav-link active" id="profile-tab" data-toggle="tab" href="#profile" role="tab" aria-controls="profile" aria-selected="true">Profile</a>
					</li>
					<li class="nav-item">
						<a class="nav-link" id="password-tab" data-toggle="tab" href="#password" role="tab" aria-controls="password" aria-selected="false">Password</a>
					</li>
					<li class="nav-item">
						<a class="nav-link" id="social-connections-tab" data-toggle="tab" href="#social-connections" role="tab" aria-controls="social-connections" aria-selected="false">Social Connections</a>
					</li>
					<li class="nav-item">
						<a class="nav-link" id="notifications-tab" data-toggle="tab" href="#notifications" role="tab" aria-controls="notifications" aria-selected="false">Notifications</a>
					</li>
				</ul>
				<div class="tab-content p-4">
					<div class="tab-pane active" id="profile" role="tabpanel" aria-labelledby="profile-tab">
						<h4 class="pb-3">Edit Profile</h4>
						<form method="POST" action="{{ route('frontend.account.profile.update') }}">

							{{ csrf_field() }}
							{!! method_field('patch') !!}

							<div class="form-group row">
								<label for="name" class="col-md-3 col-form-label">Display Name</label>
								<div class="col-md-9">
									<input type="text" name="name" id="name" class="form-control {{ $errors->has('name') ? 'is-invalid' : '' }}" value="{{ old('name') ? old('name') : $user->name }}" required>
									<div class="invalid-feedback" role="alert">{{ $errors->first('name') }}</div>
								</div>
							</div>

							<div class="form-group row">
								<label for="email" class="col-md-3 col-form-label">E-Mail</label>
								<div class="col-md-9">
									<input type="text" name="email" id="email" class="form-control {{ $errors->has('email') ? 'is-invalid' : '' }}" value="{{ old('email') ? old('email') : $user->email }}" disabled>
									<div class="invalid-feedback" role="alert">{{ $errors->first('email') }}</div>
								</div>
							</div>

							<div class="form-group row">
								<label for="location" class="col-md-3 col-form-label">Location (Optional)</label>
								<div class="col-md-9">
									<input type="text" name="location" id="location" class="form-control {{ $errors->has('location') ? 'is-invalid' : '' }}" value="{{ old('location') ? old('location') : $user->location }}">
									<div class="invalid-feedback" role="alert">{{ $errors->first('location') }}</div>
								</div>
							</div>

							<div class="form-group row">
								<label for="bio" class="col-md-3 col-form-label">About Me (Optional)</label>
								<div class="col-md-9">
									<textarea  name="bio" id="bio" class="form-control {{ $errors->has('bio') ? 'is-invalid' : '' }}" rows="4">{{ old('bio') ? old('bio') : $user->bio }}</textarea>
									<div class="invalid-feedback" role="alert">{{ $errors->first('bio') }}</div>
								</div>
							</div>

							<div class="form-group row mb-0">
								<div class="col-md-6 offset-md-3">
									<button type="submit" class="btn btn-primary">Update Profile</button>
								</div>
							</div>

						</form>
					</div>
					<div class="tab-pane" id="password" role="tabpanel" aria-labelledby="password-tab">
						<h4 class="pb-3">Change Password</h4>
						<form method="POST" action="{{ route('frontend.account.password.update') }}">

							{{ csrf_field() }}

							<div class="form-group row">
								<label for="old_password" class="col-md-3 col-form-label">Current Password</label>
								<div class="col-md-6">
									<input type="password" class="form-control{{ $errors->first('old_password', ' is-invalid') }}" id="old_password" name="old_password" required >
									<div class="invalid-feedback" role="alert">{{ $errors->first('old_password') }}</div>
								</div>
							</div>

							<div class="form-group row">
								<label for="new_password" class="col-md-3 col-form-label">New Password</label>
								<div class="col-md-6">
									<input type="password" class="form-control {{ $errors->first('new_password', 'is-invalid') }}" id="new_password" name="new_password" required >
									<div class="invalid-feedback" role="alert">{{ $errors->first('new_password') }}</div>
								</div>
							</div>

							<div class="form-group row">
								<label for="new_password_confirmation" class="col-md-3 col-form-label">Confirm New Password</label>
								<div class="col-md-6">
									<input type="password" class="form-control {{ $errors->first('new_password_confirmation', 'is-invalid') }}" id="new_password_confirmation" name="new_password_confirmation" required >
									<div class="invalid-feedback" role="alert">{{ $errors->first('new_password_confirmation') }}</div>
								</div>
							</div>

							<div class="form-group row">
								<div class="col-md-6 offset-md-3">
									<button type="submit" class="btn btn-primary">Change Password</button>
								</div>
							</div>

						</form>
					</div>
					<div class="tab-pane" id="social-connections" role="tabpanel" aria-labelledby="social-connections-tab">
						<h4 class="pb-3">Social Connections</h4>

						<div class="form-group row">
							<label class="col-md-3 col-form-label">Facebook</label>
							<div class="col-md-6">

								@if(!empty($user->google_id))

									<a href="{{ route('frontend.account.facebook.disconnect') }}" class="btn btn-danger">Disconnect Facebook</a>

								@else

									<a href="{{ route('frontend.account.facebook.redirect') }}" class="btn btn-primary">Connect to Facebook</a>

								@endif

							</div>
						</div>

						<div class="form-group row">
							<label class="col-md-3 col-form-label">Google</label>
							<div class="col-md-6">

								@if(!empty($user->google_id))

									<a href="{{ route('frontend.account.google.disconnect') }}" class="btn btn-danger">Disconnect Google</a>

								@else

									<a href="{{ route('frontend.account.google.redirect') }}" class="btn btn-primary">Connect to Google</a>

								@endif

							</div>
						</div>

					</div>
					<div class="tab-pane" id="notifications" role="tabpanel" aria-labelledby="notifications-tab">
						<h4 class="pb-3">Notifications</h4>
						<P>Coming Soon!</P>						
					</div>
				</div>
			</div>
		</div>
	</div>

@endsection
