@php

if(Route::currentRouteName() == 'frontend.forum.topic.show') 
{ 
	$routeEdit = route('frontend.forum.topic.update', $topic->id); 
	$routeDelete = route('frontend.forum.topic.destroy', $topic->id); 
}

if(Route::currentRouteName() == 'frontend.product.forum.topic.show') 
{
	$routeEdit = route('frontend.product.forum.topic.update', [$product->slug, $topic->id]); 
	$routeDelete = route('frontend.product.forum.topic.destroy', [$product->slug, $topic->id]);
}

@endphp

								<article class="post">
									<div class="post-header">
										<div class="special-heading">
											<h1>{{ $topic->subject }}</h1>
										</div>
										<ul class="post-meta h5">
											<li><i class="fa fa-clock-o"></i> {{ $topic->created_at->diffForHumans() }}</li>
											<li><i class="fa fa-user"></i> <a href="{{ route('frontend.user.show', $topic->user_id) }}">{{ $topic->user->name }}</a></li>

											@if(Route::currentRouteName() == 'frontend.forum.topic.show')

												<li><i class="fa fa-folder-open"></i> <a href="{{ route('frontend.forum.show', $topic->parent->slug) }}">{{ $topic->parent->name }}</a></li>

											@elseif(Route::currentRouteName() == 'frontend.product.forum.topic.show') 

												<li><i class="fa fa-folder-open"></i> <a href="{{ route('frontend.product.forum.show', [$product->slug, $topic->parent->slug]) }}">{{ $topic->parent->name }}</a></li>

											@endif

											<li><i class="fa fa-comments"></i> {{ $topic->replies->where('status_id', 1)->count() }} {{ str_plural('Reply', $topic->replies->where('status_id', 1)->count()) }}</li>
										</ul>
									</div>
									<div class="post-content">
										<p>{!! nl2br(e($topic->body)) !!}</p>
									</div>
									<br>
									<div class="text-right">

										@if(Auth::check())

											@if($topic->user_id == Auth::id() or Auth::user()->hasRole('admin'))

												<a data-toggle="modal" data-target="#topic-{{ $topic->id }}-edit" href="" class="btn btn-circle btn-xs btn-primary">Edit</a> 
												<a data-toggle="modal" data-target="#topic-{{ $topic->id }}-delete" href="" class="btn btn-circle btn-xs btn-danger">Delete</a>

											@endif

										@endif

										<a href="" data-toggle="modal" data-target="#topic-{{ $topic->id }}-report" class="btn btn-circle btn-xs btn-warning">Report</a>
									</div>

									<!-- START Report Modal -->
									<div class="modal fade" id="topic-{{ $topic->id }}-report">
										<div class="modal-dialog modal-lg">
											<div class="modal-content">
												<form method="post" action="{{ route('frontend.component.report.store') }}">
													<div class="modal-header">
														<h5 class="modal-title">Report Topic</h5>
														<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
													</div>
													<div class="modal-body">
														<p>Please let us know why you are reporting this content.  Your reason must be 15 characters or longer.</p>

														{{ csrf_field() }}

														<input type="hidden" name="parent_id" value="{{ $topic->id }}">
														<input type="hidden" name="parent_type" value="{{ get_class($topic) }}">

														<div class="form-group">
															<label for="body" class="form-control-label">Reason For Reporting</label>
															<textarea name="body" id="body" class="form-control" rows="8" required></textarea>
														</div>
													</div>
													<div class="modal-footer">
														<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
														<button class="btn btn-round btn-brand" type="submit">Report Topic</button>
													</div>
												</form>
											</div>
										</div>
									</div>
									<!-- END Report Modal -->

									@if(Auth::check())

										@if($topic->user_id == Auth::id() or Auth::user()->hasRole('admin'))

											<!-- START Edit Modal -->
											<div class="modal fade" id="topic-{{ $topic->id }}-edit">
												<div class="modal-dialog modal-lg">
													<div class="modal-content">
														<form method="post" action="{{ $routeEdit }}">
															<div class="modal-header">
																<h5 class="modal-title">Edit Topic</h5>
																<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
															</div>
															<div class="modal-body">

																{{ csrf_field() }}
																{!! method_field('patch') !!}

																<div class="form-group">
																	<label for="subject" class="form-control-label">Subject</label>
																	<input type="text" name="subject" id="subject" class="form-control" value="{{ $topic->subject }}" required>
																</div>
																<div class="form-group">
																	<label for="body" class="form-control-label">Body</label>
																	<textarea name="body" id="body" class="form-control" rows="8" required>{{ $topic->body }}</textarea>
																</div>
															</div>
															<div class="modal-footer">
																<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
																<button class="btn btn-round btn-brand" type="submit">Save Topic</button>
															</div>
														</form>
													</div>
												</div>
											</div>
											<!-- END Edit Modal end -->

											<!-- START Delete Modal -->
											<div class="modal fade" id="topic-{{ $topic->id }}-delete">
												<div class="modal-dialog">
													<div class="modal-content">
														<form method="post" action="{{ $routeDelete }}">
															<div class="modal-header">
																<h5 class="modal-title">Delete Topic</h5>
																<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
															</div>
															<div class="modal-body">

																{!! csrf_field() !!}
																{!! method_field('delete') !!}

																<p>Please confirm you would like to delete your topic, {{ $topic->subject }}, and any associated replies.</p> 
															</div>
															<div class="modal-footer">
																<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
																<button class="btn btn-round btn-danger" type="submit">Delete Topic</button>
															</div>
														</form>
													</div>
												</div>
											</div>
											<!-- END Delete Modal end -->

										@endif

									@endif

								</article>
								<div class="comments-area">
									<div class="special-heading">
										<h1>{{ $topic->replies->count() }} {{ str_plural('Reply', $topic->replies->count()) }}</h1>
									</div>
									<div class="comment-list">

										@foreach($topic->replies->where('parent_id', null) as $reply_first)

											<a name="comment-{{ $reply_first->id }}">
											<div class="comment">
												<div class="comment-author"><img class="avatar" src="{{ $reply_first->user->image_thumb_url }}" alt="{{ $reply_first->user->name }}" width="60" height="60"></div>
												<div class="comment-body">
													<div class="comment-meta">
														<div class="comment-meta-author h5">{{ $reply_first->subject }}</div>
														<div class="comment-meta-date">By <a href="{{ route('frontend.user.show', $reply_first->user_id )}}">{{ $reply_first->user->name }}</a> <a href="#">{{ $reply_first->created_at->diffForHumans() }}</a></div>
													</div>
													<div class="comment-content">
														<p>{!! nl2br(e($reply_first->body)) !!}</p>
													</div>
													<div class="comment-reply btn-group">

														@if(Auth::check())

															@if($reply_first->user_id == Auth::id() or Auth::user()->hasRole('admin'))

																<a data-toggle="modal" data-target="#reply-{{ $reply_first->id }}-edit" href="">Edit</a>&nbsp;&nbsp;
																<a data-toggle="modal" data-target="#reply-{{ $reply_first->id }}-delete" href="">Delete</a>&nbsp;&nbsp;

															@endif

														@endif

														<a data-toggle="collapse" href="#reply-{{ $reply_first->id }}-reply" aria-expanded="false" aria-controls="reply-{{ $reply_first->id }}-reply">Reply</a>&nbsp;&nbsp;
														<a data-toggle="modal" data-target="#reply-{{ $reply_first->id }}-report" href="">Report</a>
													</div>

													<!-- START Reply Collapse -->
													<div class="collapse" id="reply-{{ $reply_first->id }}-reply">
														<h5 class="comment-reply-title">Post a Reply</h5>

														@if (Auth::guest())

															<p><b>You need to have an account to post a reply.</b></br>
															Already have an account? <a href="{{ route('frontend.account.login') }}">Login!</a></br>
															Register for a free account <a href="{{ route('frontend.account.register') }}">here</a>.<br></p>

														@else

															<form method="post" action="{{ route('frontend.forum.topic.reply.store')}}">

																{{ csrf_field() }}

																<input type="hidden" name="topic_id" value="{{ $topic->id }}">
																<input type="hidden" name="parent_id" value="{{ $reply_first->id }}">
																<div class="form-group">
																	<textarea name="body" id="body" class="form-control {{ $errors->has('body') ? 'is-invalid' : '' }}" rows="8" placeholder="Body" required>{{ old('body') }}</textarea>
																	<div class="invalid-feedback">{{ $errors->first('body') }}</div>
																</div>
																<div class="form-submit">
																	<input class="btn btn-round btn-sm btn-brand" type="submit" value="Post Reply">
																</div>
															</form>

														@endif

													</div>
													<!-- END Reply Collapse -->

													<!-- START Report Modal -->
													<div class="modal fade" id="reply-{{ $reply_first->id }}-report">
														<div class="modal-dialog modal-lg">
															<div class="modal-content">
																<form method="post" action="{{ route('frontend.component.report.store') }}">
																	<div class="modal-header">
																		<h5 class="modal-title">Report Reply</h5>
																		<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
																	</div>
																	<div class="modal-body">
																		<p>Please let us know why you are reporting this content.  Your reason must be 15 characters or longer.</p>

																		{{ csrf_field() }}

																		<input type="hidden" name="parent_id" value="{{ $reply_first->id }}">
																		<input type="hidden" name="parent_type" value="{{ get_class($reply_first) }}">

																		<div class="form-group">
																			<label for="body" class="form-control-label">Reason For Reporting</label>
																			<textarea name="body" id="body" class="form-control" rows="8" required></textarea>
																		</div>
																	</div>
																	<div class="modal-footer">
																		<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
																		<button class="btn btn-round btn-brand" type="submit">Report Reply</button>
																	</div>
																</form>
															</div>
														</div>
													</div>
													<!-- END Report Modal -->

													@if(Auth::check())

														@if($reply_first->user_id == Auth::id() or Auth::user()->hasRole('admin'))

															<!-- START Edit Modal -->
															<div class="modal fade" id="reply-{{ $reply_first->id }}-edit">
																<div class="modal-dialog modal-lg">
																	<div class="modal-content">
																		<form method="post" action="{{ route('frontend.forum.topic.reply.update', $reply_first->id) }}">
																			<div class="modal-header">
																				<h5 class="modal-title">Edit Reply</h5>
																				<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
																			</div>
																			<div class="modal-body">

																				{{ csrf_field() }}
																				{!! method_field('patch') !!}

																				<div class="form-group">
																					<textarea name="body" id="body" class="form-control {{ $errors->has('body') ? 'is-invalid' : '' }}" rows="8" placeholder="Body" required>{{ $reply_first->body }}</textarea>
																					<div class="invalid-feedback">{{ $errors->first('body') }}</div>
																				</div>
																			</div>
																			<div class="modal-footer">
																				<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
																				<button class="btn btn-round btn-brand" type="submit">Save Reply</button>
																			</div>
																		</form>
																	</div>
																</div>
															</div>
															<!-- END Edit Modal -->

															<!-- START Delete Modal -->
															<div class="modal fade" id="reply-{{ $reply_first->id }}-delete">
																<div class="modal-dialog">
																	<div class="modal-content">
																		<form method="post" action="{{ route('frontend.forum.topic.reply.destroy', $reply_first->id) }}">
																			<div class="modal-header">
																				<h5 class="modal-title">Delete Reply</h5>
																				<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
																			</div>
																			<div class="modal-body">

																				{{ csrf_field() }}
																				{!! method_field('delete') !!}

																				<p>Please confirm you would like to delete your reply to {{ $topic->subject }} and any assoicated replies.</p> 
																			</div>
																			<div class="modal-footer">
																				<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
																				<button class="btn btn-round btn-danger" type="submit">Delete Reply</button>
																			</div>
																		</form>
																	</div>
																</div>
															</div>
															<!-- END Delete Modal -->

														@endif

													@endif

												</div>

												<div class="children">

													@foreach($reply_first->replies->sortBy('created_at') as $reply_second)

														<div class="comment" id="reply-{{ $reply_second->id }}">
															<div class="comment-author"><img class="avatar" src="{{ $reply_second->user->image_thumb_url }}" alt="{{ $reply_second->user->name }}" width="60" height="60"></div>
															<div class="comment-body">
																<div class="comment-meta">
																	<div class="comment-meta-author h5">{{ $reply_second->subject }}</div>
																	<div class="comment-meta-date">By <a href="{{ route('frontend.user.show', $reply_second->user_id )}}">{{ $reply_second->user->name }}</a> <a href="#">{{ $reply_second->created_at->diffForHumans() }}</a></div>
																</div>
																<div class="comment-content">
																	<p>{!! nl2br(e($reply_second->body)) !!}</p>
																</div>
																<div class="comment-reply btn-group">

																	@if(Auth::check())

																		@if($reply_second->user_id == Auth::id() or Auth::user()->hasRole('admin'))

																			<a data-toggle="modal" data-target="#reply-{{ $reply_second->id }}-edit" href="">Edit</a>&nbsp;&nbsp;
																			<a data-toggle="modal" data-target="#reply-{{ $reply_second->id }}-delete" href="">Delete</a>&nbsp;&nbsp;

																		@endif

																	@endif

																	<a data-toggle="modal" data-target="#reply-{{ $reply_second->id }}-report" href="">Report</a>
																</div>
															</div>
														</div>

														<!-- START Report Modal -->
														<div class="modal fade" id="reply-{{ $reply_second->id }}-report">
															<div class="modal-dialog modal-lg">
																<div class="modal-content">
																	<form method="post" action="{{ route('frontend.component.report.store') }}">
																		<div class="modal-header">
																			<h5 class="modal-title">Report Reply</h5>
																			<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
																		</div>
																		<div class="modal-body">
																			<p>Please let us know why you are reporting this content.  Your reason must be 15 characters or longer.</p>

																			{{ csrf_field() }}

																			<input type="hidden" name="parent_id" value="{{ $reply_second->id }}">
																			<input type="hidden" name="parent_type" value="{{ get_class($reply_second) }}">
																			<div class="form-group">
																				<label for="body" class="form-control-label">Reason For Reporting</label>
																				<textarea name="body" id="body" class="form-control" rows="8" required></textarea>
																			</div>
																		</div>
																		<div class="modal-footer">
																			<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
																			<button class="btn btn-round btn-brand" type="submit">Report Reply</button>
																		</div>
																	</form>
																</div>
															</div>
														</div>
														<!-- END Report Modal end -->

														@if(Auth::check())

															@if($reply_second->user_id == Auth::id() or Auth::user()->hasRole('admin'))

																<!-- START Edit Modal -->
																<div class="modal fade" id="reply-{{ $reply_second->id }}-edit">
																	<div class="modal-dialog modal-lg">
																		<div class="modal-content">
																			<form method="post" action="{{ route('frontend.forum.topic.reply.update', $reply_second->id) }}">
																				<div class="modal-header">
																					<h5 class="modal-title">Edit Reply</h5>
																					<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
																				</div>
																				<div class="modal-body">

																					{{ csrf_field() }}
																					{!! method_field('patch') !!}
																					
																					<div class="form-group">
																						<label for="body" class="form-control-label">Body</label>
																						<textarea name="body" id="body" class="form-control" rows="8" required>{{ $reply_second->body }}</textarea>
																					</div>
																				</div>
																				<div class="modal-footer">
																					<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
																					<button class="btn btn-round btn-brand" type="submit">Save Reply</button>
																				</div>
																			</form>
																		</div>
																	</div>
																</div>
																<!-- END Edit Modal -->

																<!-- START Delete Modal -->
																<div class="modal fade" id="reply-{{ $reply_second->id }}-delete">
																	<div class="modal-dialog">
																		<div class="modal-content">
																			<form method="post" action="{{ route('frontend.forum.topic.reply.destroy', $reply_second->id) }}">
																				<div class="modal-header">
																					<h5 class="modal-title">Delete Reply</h5>
																					<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
																				</div>
																				<div class="modal-body">

																					{{ csrf_field() }}
																					{!! method_field('delete') !!}

																					<p>Please confirm you would like to delete your reply.</p> 
																				</div>
																				<div class="modal-footer">
																					<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
																					<button class="btn btn-round btn-danger" type="submit">Delete Reply</button>
																				</div>
																			</form>
																		</div>
																	</div>
																</div>
																<!-- END Delete Modal -->

															@endif

														@endif

													@endforeach

												</div>
											</div>

										@endforeach

										@if($topic->replies->count() == 0)<p class="text-center">Be the first to leave a reply using the form below</p>@endif

									</div>
									<br>
									<div class="comment-respond">
										<div class="special-heading">
											<h1>Leave a Reply</h1>
										</div>

										@if (Auth::guest())

											<p><b>You need to have an account to post a reply.</b></br>
											Already have an account? <a href="{{ route('frontend.account.login') }}">Login!</a></br>
											Register for a free account <a href="{{ route('frontend.account.register') }}">here</a>.<br></p>

										@else

										<form method="post" action="{{ route('frontend.forum.topic.reply.store')}}" class="form">

											{{ csrf_field() }}

											<input type="hidden" name="topic_id" value="{{ $topic->id }}">

											<div class="row">
												<div class="col-md-12">
													<div class="form-group">
														<textarea name="body" id="body" class="form-control {{ $errors->has('body') ? 'is-invalid' : '' }}" rows="8" placeholder="Body" required>{{ old('body') }}</textarea>
														<div class="invalid-feedback">{{ $errors->first('body') }}</div>
													</div>
												</div>
											</div>

											<input class="btn btn-brand" type="submit" value="Post Reply">

										</form>

										@endif

									</div>
								</div>