@php

if(Route::currentRouteName() == 'frontend.photo.show') 
{ 
	$routeEdit = route('frontend.photo.edit', $photo->id); 
	$routeDelete = route('frontend.photo.destroy', $photo->id); 
}

if(Route::currentRouteName() == 'frontend.product.photo.show') 
{
	$routeEdit = route('frontend.product.photo.edit', [$product->slug, $photo->id]); 
	$routeDelete = route('frontend.product.photo.destroy', [$product->slug, $photo->id]);
}

@endphp

								<article class="post">
									<div class="post-header">
										<h1 class="post-title">{{ $photo->title }}</h1>
										<ul class="post-meta h5">
											<li><i class="fa fa-clock-o"></i> {{ $photo->created_at->diffForHumans() }}</li>
											<li><i class="fa fa-user"></i> <a href="{{ route('frontend.user.show', $photo->user_id) }}">{{ $photo->user->name }}</a></li>
											<li><i class="fa fa-folder-open"></i> <a href="{{ route('frontend.photo.category.show', $photo->category->slug) }}">{{ $photo->category->name }}</a></li>
											<li><i class="fa fa-star"></i> {{ $photo->rating }}</li>
											<li><i class="fa fa-comments"></i> {{ $photo->comments->count() }} {{ str_plural('Comment', $photo->comments->where('status_id', 1)->count()) }}</li>
											<!-- <li><i class="fa fa-eye"></i> {{ $photo->views->count() }} Views</a></li> -->
										</ul>
									</div>
								</article>
								<div class="row mb-3">
									<div class="col-sm-12">
										<p class="text-center"><a class="product-gallery" href="{{ $photo->image_orignal_url }}" title="{{ $photo->title }}" rel="single-image"><img src="{{ $photo->image_full_url }}" alt="{{ $photo->title }}"></a></p>
										<p class="text-right">

											@if(Auth::check())

												@if($photo->user_id == Auth::id() or Auth::user()->hasRole('admin'))

													<a href="{{ $routeEdit }}" class="btn btn-circle btn-xs btn-primary">Edit</a> 
													<a href="" data-toggle="modal" data-target="#photo-{{ $photo->id }}-delete" class="btn btn-circle btn-xs btn-danger">Delete</a>

												@endif

											@endif

											<a href="" data-toggle="modal" data-target="#photo-{{ $photo->id }}-report" class="btn btn-circle btn-xs btn-warning">Report</a>
										</p>
										<p>

											{!! nl2br(e($photo->description)) !!}

										</p>
									</div>
								</div>
								<!-- END Image--> 

								<!-- START Delete Modal -->

								@if(Auth::check())

									@if($photo->user_id == Auth::id() or Auth::user()->hasRole('admin'))

										<div class="modal fade" id="photo-{{ $photo->id }}-delete">
											<div class="modal-dialog">
												<div class="modal-content">
													<form method="post" action="{{ $routeDelete }}">
														<div class="modal-header">
															<h5 class="modal-title">Delete Photo</h5>
															<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
														</div>
														<div class="modal-body">

															{{ csrf_field() }}
															{!! method_field('delete') !!}

															<p>Please confirm you would like to delete your photo, {{ $photo->title }}, along with any associated comments and ratings.</p> 
														</div>
														<div class="modal-footer">
															<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
															<button class="btn btn-round btn-danger" type="submit">Delete Photo</button>
														</div>
													</form>
												</div>
											</div>
										</div>

									@endif

								@endif

								<!-- END Delete Modal -->

								<!-- START Report Modal -->
								<div class="modal fade" id="photo-{{ $photo->id }}-report">
									<div class="modal-dialog">
										<div class="modal-content">
											<form method="post" action="{{ route('frontend.component.report.store') }}">
												<div class="modal-header">
													<h5 class="modal-title">Report Photo</h5>
													<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
												</div>
												<div class="modal-body">
													<p>Please let us know why you are reporting this photo.  Your reason must be 15 characters or longer to be considered valid.</p>

													{{ csrf_field() }}

													<input type="hidden" name="parent_id" value="{{ $photo->id }}">
													<input type="hidden" name="parent_type" value="{{ get_class($photo) }}">
													<div class="form-group">
														<label for="body" class="form-control-label">Reason For Reporting</label>
														<textarea name="body" id="body" class="form-control" rows="5" required></textarea>
													</div>
												</div>
												<div class="modal-footer">
													<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
													<button class="btn btn-round btn-brand" type="submit">Report Photo</button>
												</div>
											</form>
										</div>
									</div>
								</div>
								<!-- END Report Modal -->

								<!-- START Tabbed Comments, Ratings and Details -->
								<ul class="nav nav-tabs">
									<li class="nav-item"><a class="nav-link active" href="#comments" data-toggle="tab">Comments ({{ $photo->comments->where('status_id', 1)->count() }})</a></li>
									<li class="nav-item"><a class="nav-link" href="#ratings" data-toggle="tab">Ratings ({{ $photo->ratings->where('status_id', 1)->count() }})</a></li>
									<li class="nav-item"><a class="nav-link" href="#details" data-toggle="tab">Photo Details</a></li>
								</ul>
								<div class="tab-content">
									<div class="tab-pane active" id="comments">

										@include('frontend/component/comment/include', ['parent' => $photo])

									</div>
									<div class="tab-pane" id="ratings">

										@include('frontend/component/rating/include', ['parent' => $photo])

									</div>
									<div class="tab-pane" id="details">
										<table class="table">
											<tbody>      
												<tr>
													<td width="30%">Title</td>
													<td width="70%">{{ $photo->title }}</td>
												</tr>
												<tr>
													<td>Rating</td>
													<td>{{ $photo->rating }}</td>
												</tr>
												<tr>
													<td>Comments</td>
													<td>{{ $photo->comments->where('status_id', 1)->count() }}</td>
												</tr>
												<tr>
													<td>Views</td>
													<td>{{ $photo->views->count() }}</td>
												</tr>
												<tr>
													<td>Category</td>
													<td><a href="{{ route('frontend.photo.category.show', $photo->category->slug ) }}">{{ $photo->category->name }}</a></td>
												</tr>
												<tr>
													<td>Related</td>
													<td>

														@foreach($photo->products->sortBy('created_at') as $product)

															{{ $loop->first ? '' : ', ' }}<a href="{{ route('frontend.product.show', $product->slug) }}">{{ $product->name }}</a>

														@endforeach

														</td>
												</tr>
												<tr>
													<td>Taken</td>
													<td>@if(!empty($photo->taken_at)) {{ $photo->taken_at->diffForHumans() }} @endif</td>
												</tr>
												<tr>
													<td>Uploaded</td>
													<td>{{ $photo->created_at->diffForHumans() }}</td>
												</tr>
												<tr>
													<td>Source</td>
													<td><a href="{{ $photo->source_url }}" target="_blank">{{ $photo->source_name }}</a></td>
												</tr>
												<tr>
													<td>Location</td>
													<td>{{ $photo->location }}</td>
												</tr>
												<tr>
													<td>Last Edited</td>
													<td>{{ $photo->updated_at->diffForHumans() }}</td>
												</tr>
												<tr>
													<td>Uploaded By</td>
													<td><a href="{{ route('frontend.user.show', $photo->user_id) }}">{{ $photo->user->name }}</a></td>
												</tr>
											</tbody>
										</table>
									</div>
								</div>
								<!-- END Tabbed Comments, Ratings and Details -->