@extends('frontend.layouts.master')

@section('title', $product->name . ' Discussion')

@section('content')

                <!-- Page Header-->
                <section class="module-page-title">
                    <div class="container">
                        <div class="row-page-title">
                            <div class="page-title-captions">
                                <h1 class="h5">{{ $product->name }} Discussion</h1>
                            </div>
                            <div class="page-title-secondary">
                                <ol class="breadcrumb">
                                    <li class="breadcrumb-item"><a href="{{ route('frontend.index') }}">Home</a></li>
                                    <li class="breadcrumb-item"><a href="{{ route('frontend.product.category.show', $product->category->slug) }}">{{ $product->category->name }}</a></li>
                                    <li class="breadcrumb-item"><a href="{{ route('frontend.product.show', $product->slug) }}">{{ $product->name }}</a></li>
                                    <li class="breadcrumb-item active">Discussion</li>
                                </ol>
                            </div>
                        </div>
                    </div>
                </section>
                <!-- Page Header end-->

                <!-- Product-->
                <section class="module">
                    <div class="container">
                        <div class="row">
                            <div class="col-lg-8">

                                <div class="special-heading">
                                    <h1>{{ $product->name }} Forums</h1>
                                </div>

                                <table class="table table-hover">
                                    <tbody>

                                        @foreach($product->category->forums->sortBy('sort_order') as $forum)

                                            <tr>
                                                <td width="55%">
                                                    <a href="{{ route('frontend.product.forum.show', [$product->slug, $forum->slug]) }}">{{ $forum->name }}</a><div class="small">{{ $forum->description }}</div>
                                                </td>
                                                <td width="10%" class="text-center">
                                                    {{ $forum->topics->where('product_id', $product->id)->count() }}<div class="small">Topics</div>
                                                </td>
                                                <td width="10%" class="text-center">
                                                    {{ $forum->replies->where('product_id', $product->id)->count() }}<div class="small">Replies</div>
                                                </td>

                                                @if( $forum->topics->where('product_id', $product->id)->count() === 0 )

                                                    <td width="55%" class="text-right">
                                                        No Topics
                                                    </td> 

                                                @else

                                                    @php

                                                        $last_topic = $forum->topics()->where('product_id', $product->id)->latest()->first();

                                                    @endphp

                                                    <td width="25%" class="text-right">
                                                        <a href="{{ route('frontend.product.forum.topic.show', [$product->slug, $last_topic->id]) }}">{{ $last_topic->subject }}</a><div class="small">{{ $last_topic->created_at->diffForHumans() }}</div>
                                                    </td>

                                                @endif

                                            </tr>

                                        @endforeach

                                    </tbody>
                                </table>

                                <div class="special-heading">
                                    <h1>Recent {{ $product->name }} Topics</h1>
                                </div>

                                @if($topics->count() == 0)

                                    <p class="text-center">There are no topics related to this {{ strtolower(str_singular($product->category->name)) }} yet.<br>Be the first to post a topic by visiting one of the forums above.</p>

                                @else

                                    <table class="table table-hover">
                                        <thead>
                                            <tr>
                                                <th width="55%">Topic</th>
                                                <th width="10%"></th>
                                                <th width="10%"></th>
                                                <th width="25%" class="text-right"> <div class="small">Latest Reply</div></th>
                                            </tr>
                                        </thead>
                                        <tbody>

                                            @foreach($topics as $topic)

                                                <tr>
                                                    <td><a href="{{ route('frontend.product.forum.topic.show', [$product->slug, $topic->id]) }}">{{ str_limit($topic->subject, 50) }}</a><div class="small">Posted by <a href="{{ route('frontend.user.show', $topic->user->id ) }}">{{ $topic->user->name }}</a> {{ $topic->created_at->diffForHumans() }}</div></td>
                                                    <td class="text-center">{{ $topic->replies->count() }}<div class="small">Replies</div></td>
                                                    <td class="text-center">{{ $topic->views->count() }}<div class="small">Views</div></td>

                                                    @if( $topic->replies->count() === 0 )

                                                        <td class="text-right">
                                                            No Replies
                                                        </td> 

                                                    @else

                                                        <td class="text-right">
                                                            <small>By <a href="{{ route('frontend.user.show', $topic->replies()->latest()->first()->user->id ) }}">{{ $topic->replies()->latest()->first()->user->name }}</a></small><div class="small">{{ $topic->replies()->latest()->first()->created_at->diffForHumans() }}</div>
                                                        </td>               

                                                    @endif

                                                </tr>

                                            @endforeach

                                        </tbody>
                                    </table>

                                @endif

                            </div>

                            <!-- Sidebar-->
                            <div class="col-lg-4">
                                <div class="sidebar">

                                    @include('frontend.product.partials.sidebar_product')

                                </div>
                            </div>
                        </div>
                    </div>
                </section>
                <!-- Product End -->

@endsection