@extends('frontend.layouts.master')

@section('title', $product->name)

@section('meta_tags')

	<meta name="description" content="Landing page for {{ $product->name }} specific content.  Photos, videos, a message board, {{ strtolower(str_singular($product->category->name)) }} specs/comparisons and more.">

@endsection

@section('content')

				<section class="module-page-title">
					<div class="container">
						<div class="row-page-title">
							<div class="page-title-captions">
								<h1 class="h5">{{ $product->name }}</h1>
							</div>
							<div class="page-title-secondary">
								<ol class="breadcrumb">
									<li class="breadcrumb-item"><a href="{{ route('frontend.index') }}">Home</a></li>
									<li class="breadcrumb-item"><a href="{{ route('frontend.product.category.show', $product->category->slug) }}">{{ $product->category->name }}</a></li>
									<li class="breadcrumb-item active">{{ $product->name }}</li>
								</ol>
							</div>
						</div>
					</div>
				</section>

				<section class="module">
					<div class="container">
						<div class="row">
							<div class="col-lg-8">
								<article class="post">
									<div class="post-header">
										<div class="special-heading">
											<h1>{{ $product->name }}</h1>
										</div>
										<ul class="post-meta h5">
											<li><i class="fa fa-star"></i> {{ $product->rating }}</li>
											<li><i class="fa fa-photo"></i> {{ $product->photos->count() }} Photos</li>
											<li><i class="fa fa-film"></i> {{ $product->videos->count() }} Videos</li>
											<li><i class="fa fa-bullhorn"></i> {{ $product->topics->count() }} Topics</li>
										</ul>
									</div>
								</article>
								<div class="row">
									<div class="col-md-12 text-center mb-2">

										@if($product->images->count() == 0 )

											<a class="product-gallery" href="#"><img src="/uploads/product/image/default_square_large.jpg" alt="{{ $product->name }}"></a>

										@else

											<a class="product-gallery" href="{{ $product->images->first()->image_full_url }}"><img src="{{ $product->images->first()->image_full_url }}" alt="{{ $product->images->first()->title }}"></a>

										@endif
										
									</div>
								</div>

								<div class="row text-center mb-10">

										@foreach($product->images->sortBy('sort_order')->slice('1') as $image)

												<div class="col-md-2 px-10 py-1">
													<a class="product-gallery" href="{{ $image->image_full_url }}"><img src="{{ $image->image_square_small_url }}" class="img-fluid" alt="{{ $image->title }}"></a>
												</div>

										@endforeach

								</div>

								<div class="row">
									<div class="col-md-12">
										<div class="module-title text-center mt-5">
											<h2>{{ $product->name }} Specifications</h2>
											<p class="font-serif mb-5">All the details about this {{ strtolower(str_singular($product->category->name)) }} as found on the manufacture's website.</p>
										</div>
									</div>
								</div>
								<div class="special-heading mt-0">
									<h4 class="mt-0">Highlights</h4>
								</div>
								<div class="row clients-row">

									@foreach($attributes as $attribute)

										@if($loop->index == 4 || $loop->index == 8)

											</div>
											<div class="row clients-row">

										@endif

										<div class="col-md-3 col-sm-6">
											<div class="client"><h4><i class="fas {{ $attribute->icon }} fa-4x mt-2 mb-4" style="color:#3498db;"></i><br>{{ $attribute->name }}:<br><br><big><big><b>

												@php

													$value = null;
													$value = $product->values->where('attribute_id', $attribute->id)->first();

												@endphp

												@if($attribute->type_id == '1' || $attribute->type_id == '2' || $attribute->type_id == '5')

														@if(!empty($value))

															{{ $attribute->unit_before }}{{ $value->value }}{{ $attribute->unit_after }}

														@endif

												@elseif($attribute->type_id == '3')

													@php

														$single_select_option = null;

														if(isset($value))
														{
															$single_select_option = $options->where('id', $value->value)->first();
														}

													@endphp

													@if(isset($single_select_option)){{ $attribute->unit_before }}{{ $single_select_option->name }}{{ $attribute->unit_after }}@endif

												@elseif($attribute->type_id == '4')

													@php

														$multiple_select_options = null;
														if(isset($value)) { $multiple_select_options = explode(',', $value->value); }

													@endphp
														
													@foreach($multiple_select_options as $option)

														@php $value = $options->where('id', $option)->first(); @endphp

														{{ $value->name }}@if($loop->remaining > 0),@endif

													@endforeach

												@elseif($attribute->type_id == '6')

												@elseif($attribute->type_id == '7')

												@endif

											</b></big></big></h4></div>
										</div>

									@endforeach

								</div>
								<div class="special-heading mt-5">
									<h4>Details</h4>
								</div>
								<div class="row">
									<div class="col-md-12">
										<ul class="nav nav-tabs">

											@foreach($attribute_groups->sortBy('sort_order') as $attribute_group)

												<li class="nav-item"><a class="nav-link @if($loop->index == 0) active @endif" href="#{{ $attribute_group->name }}" data-toggle="tab">{{ $attribute_group->name }}</a></li>

											@endforeach

										</ul>
										<div class="tab-content">

											@foreach($attribute_groups->sortBy('sort_order') as $attribute_group)

												<div class="tab-pane @if($loop->index == 0) in active @endif" id="{{ $attribute_group->name }}">
													<dl class="row">

														@foreach($attribute_group->attributes->sortBy('sort_order') as $attribute)

															@php

																$value = null;
																$value = $product->values->where('attribute_id', $attribute->id)->first();

															@endphp

															@if($attribute->type_id == '1' || $attribute->type_id == '2' || $attribute->type_id == '5')

																<dt class="col-md-4 mb-2">{{ $attribute->name }}</dt>
																<dd class="col-md-4 mb-2">

																	@if(!empty($value))

																		{{ $attribute->unit_before }}{{ $value->value }}{{ $attribute->unit_after }}

																	@endif

																</dd>
																<dd class="col-md-4 mb-2"></dd>

															@elseif($attribute->type_id == '3')

																@php

																	$single_select_option = null;

																	if(isset($value))
																	{
																		$single_select_option = App\Models\Product\Attribute\Option::find($value->value);
																	}

																@endphp

																<dt class="col-md-4 mb-2">{{ $attribute->name }}</dt>
																<dd class="col-md-4 mb-2">@if(isset($single_select_option)){{ $attribute->unit_before }}{{ $single_select_option->name }}{{ $attribute->unit_after }}@endif</dd>
																<dd class="col-md-4 mb-2"></dd>

															@elseif($attribute->type_id == '4')

																@php

																	$multiple_select_options = null;
																	if(isset($value)) { $multiple_select_options = explode(',', $value->value); }

																@endphp

																<dt class="col-md-4 mb-2">{{ $attribute->name }}</dt>
																<dd class="col-md-4 mb-2">
																	
																	@foreach($multiple_select_options as $option)

																		@php $value = \App\Models\Product\Attribute\Option::find($option) @endphp

																		{{ $value->name }}@if($loop->remaining > 0),@endif

																	@endforeach

																</dd>
																<dd class="col-md-4 mb-2"></dd>

															@elseif($attribute->type_id == '6')

																<dt class="col-md-4 mb-2">{{ $attribute->name }}</dt>
																<dd class="col-md-4 mb-2"></dd>
																<dd class="col-md-4 mb-2"></dd>

															@elseif($attribute->type_id == '7')

																<dt class="col-md-4 mb-2">{{ $attribute->name }}</dt>
																<dd class="col-md-4 mb-2"></dd>
																<dd class="col-md-4 mb-2"></dd>

															@elseif($attribute->type_id == '8')

																<dt class="col-md-4 mb-2">{{ $attribute->name }}</dt>
																<dd class="col-md-4 mb-2">
																	
																	@if(!empty($value))

																		<a href="{{ $value->value }}" target="_blank">{{ $product->name }}</a>

																	@endif

																</dd>
																<dd class="col-md-4 mb-2"></dd>

															@endif
													
														@endforeach

													</dl>
												</div>

											@endforeach

										</div>
									</div>
								</div>
							</div>
							<div class="col-lg-4">
								<div class="sidebar">

									@include('frontend.product.partials.sidebar_product')

								</div>
							</div>
						</div>
					</div>
				</section>
				<!-- Product End -->

@endsection