@php

if(Route::currentRouteName() == 'frontend.video.show') 
{ 
	$routeEdit = route('frontend.video.edit', $video->id); 
	$routeDelete = route('frontend.video.destroy', $video->id); 
}

if(Route::currentRouteName() == 'frontend.product.video.show') 
{
	$routeEdit = route('frontend.product.video.edit', [$product->slug, $video->id]); 
	$routeDelete = route('frontend.product.video.destroy', [$product->slug, $video->id]);
}

@endphp
								<!-- START Video-->
								<article class="post">
									<div class="post-header">
										<h1 class="post-title">{{ $video->title }}</h1>
										<ul class="post-meta h5">
											<li><i class="fa fa-clock-o"></i> {{ $video->created_at->diffForHumans() }}</li>
											<li><i class="fa fa-user"></i> <a href="{{ route('frontend.user.show', $video->user_id) }}">{{ $video->user->name }}</a></li>
											<li><i class="fa fa-folder-open"></i> <a href="{{ route('frontend.video.category.show', $video->category->slug) }}">{{ $video->category->name }}</a></li>
											<li><i class="fa fa-star"></i> {{ $video->rating }}</li>
											<li><i class="fa fa-comments"></i> {{ $video->comments->count() }} {{ str_plural('Comment', $video->comments->where('status_id', 1)->count()) }}</li>
											<!-- <li><i class="fa fa-eye"></i> {{ $video->views->count() }} Views</a></li> -->
										</ul>
									</div>
									<div class="post-preview">
										<iframe class="embed-responsive-item" src="//www.youtube.com/embed/{{ $video->youtube_id }}" allowfullscreen></iframe><br>
										<div class="text-right">

											@if(Auth::check())

												@if($video->user_id == Auth::id() or Auth::user()->hasRole('admin'))

													<a href="{{ $routeEdit }}" class="btn btn-circle btn-xs btn-primary">Edit</a> 
													<a href="" data-toggle="modal" data-target="#video-{{ $video->id }}-delete" class="btn btn-circle btn-xs btn-danger">Delete</a>

												@endif

											@endif

											<a href="" data-toggle="modal" data-target="#video-{{ $video->id }}-report" class="btn btn-circle btn-xs btn-warning">Report</a>
										</div>
									</div>
									<div class="post-content">
										<p>{!! nl2br(e($video->description)) !!}</p>
									</div>
								</article>
								<!-- END Video--> 

								<!-- START Delete Modal -->

								@if(Auth::check())

									@if($video->user_id == Auth::id() or Auth::user()->hasRole('admin'))

										<div class="modal fade" id="video-{{ $video->id }}-delete">
											<div class="modal-dialog">
												<div class="modal-content">
													<form method="post" action="{{ $routeDelete }}">
														<div class="modal-header">
															<h5 class="modal-title">Delete Video</h5>
															<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
														</div>
														<div class="modal-body">

															{{ csrf_field() }}
															{!! method_field('delete') !!}

															<p>Please confirm you would like to delete your video, {{ $video->title }}, along with any associated comments and ratings.</p> 
														</div>
														<div class="modal-footer">
															<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
															<button class="btn btn-round btn-danger" type="submit">Delete Video</button>
														</div>
													</form>
												</div>
											</div>
										</div>

									@endif

								@endif

								<!-- END Delete Modal -->

								<!-- START Report Modal -->
								<div class="modal fade" id="video-{{ $video->id }}-report">
									<div class="modal-dialog">
										<div class="modal-content">
											<form method="post" action="{{ route('frontend.component.report.store') }}">
												<div class="modal-header">
													<h5 class="modal-title">Report Video</h5>
													<button class="close" type="button" data-dismiss="modal" aria-label="Close"><span>&times;</span></button>
												</div>
												<div class="modal-body">
													<p>Please let us know why you are reporting this video.  Your reason must be 15 characters or longer to be considered valid.</p>

													{{ csrf_field() }}

													<input type="hidden" name="parent_id" value="{{ $video->id }}">
													<input type="hidden" name="parent_type" value="{{ get_class($video) }}">
													<div class="form-group">
														<label for="body" class="form-control-label">Reason For Reporting</label>
														<textarea name="body" id="body" class="form-control" rows="5" required></textarea>
													</div>
												</div>
												<div class="modal-footer">
													<button class="btn btn-round btn-gray" type="button" data-dismiss="modal">Cancel</button>
													<button class="btn btn-round btn-brand" type="submit">Report Video</button>
												</div>
											</form>
										</div>
									</div>
								</div>
								<!-- End Report Modal -->

								<!-- START Comments, Ratings and Details -->
								<ul class="nav nav-tabs">
									<li class="nav-item"><a class="nav-link active" href="#comments" data-toggle="tab">Comments ({{ $video->comments->where('status_id', 1)->count() }})</a></li>
									<li class="nav-item"><a class="nav-link" href="#ratings" data-toggle="tab">Ratings ({{ $video->ratings->where('status_id', 1)->count() }})</a></li>
									<li class="nav-item"><a class="nav-link" href="#details" data-toggle="tab">Video Details</a></li>
								</ul>
								<div class="tab-content">

									<div class="tab-pane active" id="comments">

										@include('frontend/component/comment/include', ['parent' => $video])

									</div>
									<div class="tab-pane" id="ratings">

										@include('frontend/component/rating/include', ['parent' => $video])

									</div>
									<div class="tab-pane" id="details">
										<table class="table">
											<tbody>      
												<tr>
													<td width="30%">Title</td>
													<td width="70%">{{ $video->title }}</td>
												</tr>
												<tr>
													<td>Rating</td>
													<td>{{ $video->rating }}</td>
												</tr>
												<tr>
													<td>Comments</td>
													<td>{{ $video->comments->where('status_id', 1)->count() }}</td>
												</tr>
												<tr>
													<td>Views</td>
													<td>{{ $video->views->count() }}</td>
												</tr>
												<tr>
													<td>Category</td>
													<td><a href="{{ route('frontend.video.category.show', $video->category->slug) }}">{{ $video->category->name }}</a></td>
												</tr>
												<tr>
													<td>Related</td>
													<td>

														@foreach($video->products->sortBy('created_at') as $product)

															{{ $loop->first ? '' : ', ' }}<a href="{{ route('frontend.product.show', $product->slug) }}">{{ $product->name }}</a>

														@endforeach

														</td>
												</tr>
												<tr>
													<td>Taken</td>
													<td>@if(!empty($video->taken_at)) {{ $video->taken_at->diffForHumans() }} @endif</td>
												</tr>
												<tr>
													<td>Uploaded By</td>
													<td><a href="{{ route('frontend.user.show', $video->user_id) }}">{{ $video->user->name }}</a></td>
												</tr>
												<tr>
													<td>Source</td>
													<td><a href="{{ $video->source_url }}" target="_blank">{{ $video->source_name }}</a></td>
												</tr>
												<tr>
													<td>Location</td>
													<td>{{ $video->location }}</td>
												</tr>
												<tr>
													<td>Uploaded</td>
													<td>{{ $video->created_at->diffForHumans() }}</td>
												</tr>
												<tr>
													<td>Last Edited</td>
													<td>{{ $video->updated_at->diffForHumans() }}</td>
												</tr>
											</tbody>
										</table>
									</div>
								</div>
								<!-- END Comments, Ratings and Details -->